package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.ServiceType;

/**
 * ServiceTypeMapper接口
 * 
 * @author ruoyi
 * @date 2024-02-24
 */
public interface ServiceTypeMapper  extends BaseMapper<ServiceType>
{
    /**
     * 查询ServiceType
     * 
     * @param id ServiceType主键
     * @return ServiceType
     */
    public ServiceType selectServiceTypeById(Long id);

    /**
     * 查询ServiceType列表
     * 
     * @param serviceType ServiceType
     * @return ServiceType集合
     */
    public List<ServiceType> selectServiceTypeList(ServiceType serviceType);

    /**
     * 新增ServiceType
     * 
     * @param serviceType ServiceType
     * @return 结果
     */
    public int insertServiceType(ServiceType serviceType);

    /**
     * 修改ServiceType
     * 
     * @param serviceType ServiceType
     * @return 结果
     */
    public int updateServiceType(ServiceType serviceType);

    /**
     * 删除ServiceType
     * 
     * @param id ServiceType主键
     * @return 结果
     */
    public int deleteServiceTypeById(Long id);

    /**
     * 批量删除ServiceType
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteServiceTypeByIds(Long[] ids);
}
